==> apache-camel-3.1.0-src.zip: apache-camel-3.1.0/components/camel-spring/src/test/java/org/apache/camel/spring/produce/ProduceTemplateWithTwoCamelContextTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.produce;

import org.apache.camel.EndpointInject;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.spring.SpringRunWithTestSupport;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;

@ContextConfiguration
public class ProduceTemplateWithTwoCamelContextTest extends SpringRunWithTestSupport {
    @Autowired
    protected ProducerTemplate producer;
    
    @EndpointInject("mock:result")
    protected MockEndpoint result;

    @Test
    public void testProducerTemplate() throws Exception {
        result.expectedBodiesReceived("hello");
        // lets send a message
        producer.sendBody("direct:start", "hello");
        result.assertIsSatisfied();
    }
}

==> apache-camel-3.4.3-src.zip: apache-camel-3.4.3/components/camel-spring/src/test/java/org/apache/camel/spring/produce/ProduceTemplateWithTwoCamelContextTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.produce;

import org.apache.camel.EndpointInject;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.spring.SpringRunWithTestSupport;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;

@ContextConfiguration
public class ProduceTemplateWithTwoCamelContextTest extends SpringRunWithTestSupport {
    @Autowired
    protected ProducerTemplate producer;
    
    @EndpointInject("mock:result")
    protected MockEndpoint result;

    @Test
    public void testProducerTemplate() throws Exception {
        result.expectedBodiesReceived("hello");
        // lets send a message
        producer.sendBody("direct:start", "hello");
        result.assertIsSatisfied();
    }
}
